Module codec

Module codec 

Length-prefixed framing codec for walrus wire protocol.

Wire format: [u32 BE length][protobuf payload]. The length is the byte count of the payload only (not including the 4-byte header). Generic over AsyncRead/AsyncWrite — used by both UDS and TCP transports.

Enums

FrameError
Errors that can occur during frame read/write.

Functions

read_message
Read a length-prefixed protobuf frame and deserialize into a typed message.
write_message
Write a typed message as a length-prefixed protobuf frame.