Module client

Module client 

Messages sent by the client to the gateway.

Structs

DownloadRequest
Request download of a model’s files with progress reporting.
HubRequest
Install or uninstall a hub package.
SendRequest
Send a message to an agent and receive a complete response.
StreamRequest
Send a message to an agent and receive a streamed response.

Enums

ClientMessage
Messages sent by the client to the gateway.
HubAction
Hub package action.