pub enum ClientMessage {
Show 17 variants
Send {
agent: CompactString,
content: String,
session: Option<u64>,
sender: Option<CompactString>,
},
Stream {
agent: CompactString,
content: String,
session: Option<u64>,
sender: Option<CompactString>,
},
Download {
model: CompactString,
},
Ping,
Hub {
package: CompactString,
action: HubAction,
},
Sessions,
Kill {
session: u64,
},
Tasks,
KillTask {
task_id: u64,
},
Approve {
task_id: u64,
response: String,
},
Evaluate {
agent: CompactString,
content: String,
session: Option<u64>,
sender: Option<CompactString>,
},
SubscribeTasks,
Downloads,
SubscribeDownloads,
GetConfig,
SetConfig {
config: String,
},
MemoryQuery {
query: MemoryOp,
},
}Expand description
Messages sent by the client to the gateway.
Variants
Send
Send a message to an agent and receive a complete response.
Fields
agent: CompactStringTarget agent identifier.
sender: Option<CompactString>Sender identity. None = local.
Stream
Send a message to an agent and receive a streamed response.
Fields
agent: CompactStringTarget agent identifier.
sender: Option<CompactString>Sender identity. None = local.
Download
Request download of a model’s files with progress reporting.
Fields
model: CompactStringHuggingFace model ID (e.g. “microsoft/Phi-3.5-mini-instruct”).
Ping
Ping the server (keepalive).
Hub
Install or uninstall a hub package.
Fields
package: CompactStringPackage identifier in scope/name format.
Sessions
List active sessions.
Kill
Kill (close) a session.
Tasks
List tasks in the task registry.
KillTask
Kill (cancel) a task.
Approve
Approve a blocked task’s inbox item.
Evaluate
Evaluate whether the agent should respond to a message.
Used by channel loops for group-chat gating (DD#39). Returns
ServerMessage::Evaluation with a boolean decision.
Fields
agent: CompactStringTarget agent identifier.
sender: Option<CompactString>Sender identity. None = local.
SubscribeTasks
Subscribe to task lifecycle events (streaming).
Downloads
List downloads in the download registry.
SubscribeDownloads
Subscribe to download lifecycle events (streaming).
GetConfig
Get the full daemon config as JSON.
SetConfig
Replace the full daemon config from JSON.
MemoryQuery
Query the memory graph.