pub enum Msg {
Show 20 variants
Send(SendMsg),
Stream(StreamMsg),
Ping(Ping),
Hub(HubMsg),
Sessions(Sessions),
Kill(KillMsg),
Tasks(Tasks),
KillTask(KillTaskMsg),
Approve(ApproveMsg),
SubscribeTasks(SubscribeTasks),
Downloads(Downloads),
SubscribeDownloads(SubscribeDownloads),
GetConfig(GetConfig),
SetConfig(SetConfigMsg),
ServiceQuery(ServiceQueryMsg),
GetServiceSchema(GetServiceSchemaMsg),
GetAllSchemas(GetAllSchemasMsg),
GetServices(GetServicesMsg),
SetServiceConfig(SetServiceConfigMsg),
Reload(ReloadMsg),
}Variants
Send(SendMsg)
Stream(StreamMsg)
Ping(Ping)
Hub(HubMsg)
Sessions(Sessions)
Kill(KillMsg)
Tasks(Tasks)
KillTask(KillTaskMsg)
Approve(ApproveMsg)
SubscribeTasks(SubscribeTasks)
Field 10 removed — reserved to prevent accidental reuse.
Downloads(Downloads)
SubscribeDownloads(SubscribeDownloads)
GetConfig(GetConfig)
SetConfig(SetConfigMsg)
ServiceQuery(ServiceQueryMsg)
GetServiceSchema(GetServiceSchemaMsg)
GetAllSchemas(GetAllSchemasMsg)
GetServices(GetServicesMsg)
SetServiceConfig(SetServiceConfigMsg)
Reload(ReloadMsg)
Implementations
Sourceimpl Msg
impl Msg
Sourcepub fn merge(
field: &mut Option<Msg>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Msg>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.