Messages sent by the client to the gateway.
Structs
- Download
Request - Request download of a model’s files with progress reporting.
- HubRequest
- Install or uninstall a hub package.
- Send
Request - Send a message to an agent and receive a complete response.
- Stream
Request - Send a message to an agent and receive a streamed response.
Enums
- Client
Message - Messages sent by the client to the gateway.
- HubAction
- Hub package action.