ClientMessage

Enum ClientMessage 

pub enum ClientMessage {
Show 14 variants Send { agent: CompactString, content: String, }, Stream { agent: CompactString, content: String, }, ClearSession { agent: CompactString, }, ListAgents, AgentInfo { agent: CompactString, }, ListMemory, GetMemory { key: String, }, Download { model: CompactString, }, ReloadSkills, McpAdd { name: CompactString, command: String, args: Vec<String>, env: BTreeMap<String, String>, }, McpRemove { name: CompactString, }, McpReload, McpList, Ping,
}
Messages sent by the client to the gateway.

Variants



Send

Send a message to an agent and receive a complete response.

Fields

agent: CompactString

Target agent identifier.

content: String

Message content.



Stream

Send a message to an agent and receive a streamed response.

Fields

agent: CompactString

Target agent identifier.

content: String

Message content.



ClearSession

Clear the session history for an agent.

Fields

agent: CompactString

Target agent identifier.



ListAgents

List all registered agents.



AgentInfo

Get detailed info for a specific agent.

Fields

agent: CompactString

Agent name.



ListMemory

List all memory entries.



GetMemory

Get a specific memory entry by key.

Fields

key: String

Memory key.



Download

Request download of a model’s files with progress reporting.

Fields

model: CompactString

HuggingFace model ID (e.g. “microsoft/Phi-3.5-mini-instruct”).



ReloadSkills

Reload skills from disk.



McpAdd

Add an MCP server to config and reload.

Fields

name: CompactString

Server name.

command: String

Command to spawn.

args: Vec<String>

Command arguments.

env: BTreeMap<String, String>

Environment variables.



McpRemove

Remove an MCP server from config and reload.

Fields

name: CompactString

Server name to remove.



McpReload

Reload MCP servers from walrus.toml.



McpList

List connected MCP servers and their tools.



Ping

Ping the server (keepalive).